##  Importing Collections
Users with the appropriate permissions can import collections that are based on SAP LeanIX best practices. This creates collection groups for each SAP LeanIX product available in the workspace and populates them with collections for common use cases. Relevant reports are automatically added to these collections, but no diagrams are automatically created or added.
To import collections, in the Manage Collections overlay, click Import SAP LeanIX Best Practices. You can modify imported collections if needed.
